""" Output helpers """

import logging
import os

log = logging.getLogger(__name__)

# Keep trace of all ouput files opened
fds = {}


def create_directory(dir_path):
    if os.path.isdir(dir_path):
        return True
    dirs = [path for path in dir_path.split(os.path.sep) if path]
    for idx in range(len(dirs)):
        subdir_path = os.path.sep.join(dirs[0:idx + 1])
        if dir_path.startswith(os.path.sep):
            # Restore heading slash
            subdir_path = os.path.sep + subdir_path
        if os.path.isdir(subdir_path):
            continue
        os.mkdir(subdir_path)
    return True


def open_from_input_filepath(input_filepath, options):
    if input_filepath in fds:
        return fds[input_filepath]
    input_dir_paths = [
        path for path in options.input.split(os.path.sep)
        if path
    ]
    output_dir_paths = [
        path for path in options.output.split(os.path.sep)
        if path
    ]
    input_file_paths = [
        path for path in input_filepath.split(os.path.sep)
        if path
    ]
    output_filepath = os.path.sep.join(
        output_dir_paths + input_file_paths[len(input_dir_paths):]
    )
    if output_filepath.endswith('.cfg'):
        output_filepath = output_filepath[0:len(output_filepath) - 4] + '.conf'
    if options.output.startswith(os.path.sep):
        # Restore heading slash
        output_filepath = os.path.sep + output_filepath
    log.debug(
        'open_from_input_filepath(%s): output file path = "%s"',
        input_filepath, output_filepath
    )
    create_directory(os.path.dirname(output_filepath))
    # pylint: disable=consider-using-with
    fds[input_filepath] = open(output_filepath, 'w', encoding=options.output_encoding)
    return fds[input_filepath]


def close_all():
    for fd_name in fds:  # pylint: disable=consider-using-dict-items
        fds[fd_name].close()
