""" Test Icinga object parsing: parse a file and dump loaded objects """
from argparse import ArgumentParser
import logging

from icinga1_objects_upgrader.icinga1 import parse_file, format_object


def main(argv=None):
    """ Entry point of the script """

    parser = ArgumentParser(description=__doc__)

    parser.add_argument(
        '-d', '--debug',
        action="store_true",
        dest="debug",
        help="Enable debug mode"
    )

    parser.add_argument(
        action="store",
        type=str,
        dest="filepath",
        help="Icinga config file path to parse"
    )

    options = parser.parse_args(argv)

    logformat = '%(asctime)s - Tests LDAP - %(levelname)s - %(message)s'
    if options.debug:
        loglevel = logging.DEBUG
    else:
        loglevel = logging.INFO

    logging.basicConfig(level=loglevel, format=logformat)

    config_objects = parse_file(options.filepath)
    for config_obj_type in config_objects:  # pylint: disable=consider-using-dict-items
        for config_obj in config_objects[config_obj_type]:
            print(format_object(config_obj) + "\n")
